OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ali želite dodati oddaljeno mesto uporabe {name} uporabnika {owner}@{remote}?",
    "Remote share" : "Oddaljeno mesto za souporabo",
    "Remote share password" : "Geslo za oddaljeno souporabo",
    "Cancel" : "Prekliči",
    "Add remote share" : "Dodaj oddaljeno mesto za souporabo",
    "Invalid Federated Cloud ID" : "Neveljaven ID zveznega oblaka",
    "Server to server sharing is not enabled on this server" : "Na tem strežniku souporaba s strežnika na strežnik ni omogočena.",
    "Couldn't establish a federated share." : "Ni mogoče vzpostaviti zveznega mesta za souporabo.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Zvezne povezave za souporabo ni mogoče ustvariti. Morda je navedeno napačno geslo.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Zahteva za zvezno souporabo je poslana, prejeli boste povabilo. Preverite obvestila.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Zvezne povezave za souporabo ni mogoče ustvariti. Kaže, da je podana zahteva za povezavo z nepodprto staro različico oblaka (Nextzcloud ≤ 9).",
    "It is not allowed to send federated group shares from this server." : "S tega strežnika ni dovoljeno pošiljati povabil za skupinsko souporabo prek zvezne povezave.",
    "Federated shares require read permissions" : "Zvezna mesta souporabe zahtevajo dovoljenja za branje mape",
    "File is already shared with %s" : "Datoteka je že v souporabi pri %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Omogočanje souporabe %1$s je spodletelo, ker ni mogoče najti %2$s. Najverjetneje je strežnik nedosegljiv, ali pa je v uporabo neustrezno potrdilo podpisa.",
    "Could not find share" : "Mape v souporabi ni mogoče najti",
    "Federated sharing" : "Souporaba v zveznem oblaku",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Povezavo do {share} ste prejeli kot oddaljeno mesto uporabnika {user} (v imenu {behalf})",
    "You received {share} as a remote share from {user}" : "Povezavo do {share} ste prejeli kot oddaljeno mesto uporabnika {user}",
    "Accept" : "Sprejmi",
    "Decline" : "Zavrni",
    "Federated Cloud Sharing" : "Souporaba zveznega oblaka",
    "Sharing" : "Souporaba",
    "Federated file sharing" : "Souporaba v zveznem oblaku",
    "Provide federated file sharing across servers" : "Omogoči zvezno souporabo prek različnih strežnikov",
    "Unable to update federated files sharing config" : "Ni mogoče posodobiti nastavitev zvezne souporabe datotek",
    "Federated Cloud" : "Zvezni oblak",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Souporaba različnih predmetov je mogoča s komerkoli, ki uporablja strežnik Nextcloud oziroma katerikoli strežnik, skladen s storitvami Open Cloud Mesh (OCM). Vpisati je treba zgolj njihov zvezni naslov ID v polje souporabe, ki je zapisano v obliki oseba@domena-oblaka.si oziroma oseba@domena.si/oblak.",
    "Your Federated Cloud ID:" : "ID zveznega oblaka:",
    "Share it so your friends can share files with you:" : "Objavite naslov in omogočite souporabo s prijatelji:",
    "Facebook" : "Facebook",
    "Twitter" : "Račun Twitter",
    "Diaspora" : "Diaspora",
    "Add to your website" : "Dodaj na spletišče",
    "Share with me via Nextcloud" : "Omogoči souporabo z oblaka Nextcloud",
    "HTML Code:" : "Koda HTML:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Souporaba z določilom ID #Zveznega oblaka Nextcloud ; več podrobnosti je na naslovu {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Omogoči souporabo z #Določilom ID zveznega oblaka Nextcloud",
    "Cloud ID copied to the clipboard" : "Določilo ID oblaka je kopirano v odložišče",
    "Copy to clipboard" : "Kopiraj v odložišče",
    "Clipboard is not available" : "Odložišče ni na voljo",
    "Copied!" : "Kopirano!",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Nastavljanje souporabe %1$s je spodletelo, ker je predmet že v souporabi z uporabnikom %2$s.",
    "Not allowed to create a federated share with the same user" : "Ni dovoljeno ustvariti mesta souporabe zveznega oblaka z istim uporabnikom",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Prilagodite možnosti, kako si lahko uporabniki izmenjujejo vsebino med strežniki. Nastavitev vključuje dejavnosti me uporabniki na tem strežniku in med zveznimi povezavami z zunanjimi strežniki.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Dovoli uporabnikom tega strežnika pošiljanje povezav za souporabo na druge strežnike (možnost omogoči tudi dostop prek WebDAV do javnih povezav)",
    "Allow users on this server to receive shares from other servers" : "Dovoli uporabnikom tega strežnika sprejemanje map v souporabo z drugih strežnikov",
    "Allow users on this server to send shares to groups on other servers" : "Dovoli uporabnikom tega strežnika pošiljanje map za souporabo v skupine na drugih strežnikih",
    "Allow users on this server to receive group shares from other servers" : "Dovoli uporabnikom tega strežnika sprejemanje skupinskih mest souporabe z drugih strežnikov",
    "Search global and public address book for users" : "Preišči javne in splošne imenike za uporabnike",
    "Allow users to publish their data to a global and public address book" : "Dovoli uporabnikom objavljanje podatkov v splošnem in javnem imeniku"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
